@@ -915,22 +915,18 @@ function cdproject {
 #
 mktmpenv() {
     typeset tmpenvname
+    typeset RC
 
-    # Generate a unique temporary name, if one is not given.
-    if [ $# -eq 0 ]
+    # Generate a unique temporary name
+    tmpenvname=$("$VIRTUALENVWRAPPER_PYTHON" -c 'import uuid; print uuid.uuid4()' 2>/dev/null)
+    if [ -z "$tmpenvname" ]
     then
-        tmpenvname=$("$VIRTUALENVWRAPPER_PYTHON" -c 'import uuid; print uuid.uuid4()' 2>/dev/null)
-        if [ -z "$tmpenvname" ]
-        then
-            # This python does not support uuid
-            tmpenvname=$("$VIRTUALENVWRAPPER_PYTHON" -c 'import random; print hex(random.getrandbits(64))[2:-1]' 2>/dev/null)
-        fi
-        mkvirtualenv "$tmpenvname"
-    else
-        mkvirtualenv "$@"
+        # This python does not support uuid
+        tmpenvname=$("$VIRTUALENVWRAPPER_PYTHON" -c 'import random; print hex(random.getrandbits(64))[2:-1]' 2>/dev/null)
     fi
 
     # Create the environment
+    mkvirtualenv "$@" "$tmpenvname"
     RC=$?
     if [ $RC -ne 0 ]
     then
